@@ -80,7 +80,7 @@ def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que
     if c_componente[1] == None:
       c = "\\cdots"
     else:
-      c = sympy.latex(Redondear(mascara))
+      c = sympy.latex(Redondear(c_componente[1]))
     
     texto = a + b + c
       #texto = texto.replace("text", Estilo)
